#
# spec file for package freedoom
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           freedoom
Version:        0.13.0
Release:        1.4
Summary:        Replacement game files for Doom game engines
License:        BSD-3-Clause
Group:          Amusements/Games/3D/Shoot
URL:            https://freedoom.github.io/

#Git-Web:       http://github.com/freedoom/freedoom
#Git-Clone:     git://github.com/freedoom/freedoom
Source:         https://github.com/freedoom/freedoom/releases/download/v%version/freedoom-v%version.zip
BuildArch:      noarch
BuildRequires:  unzip

%description
Though the Doom engine source code is libre, the original game data
(graphics, maps, etc.) is not. Freedoom is an alternate game data set
that can be used with a Doom engine, such as prboom-plus,
chocolate-doom or gzdoom, to form a free Doom-based game.

%prep
%autosetup -n %name-v%version

%build
# Game data files. Nothing to build!

%install
install -Dpm0644 freedoom1.wad %buildroot/%_datadir/doom/freedoom1.wad
install -Dpm0644 freedoom2.wad %buildroot/%_datadir/doom/freedoom2.wad

%post
echo "NOTE: FreeDoom WAD files are no longer named doom.wad/doom2.wad, and you may need to explicitly specify them now when starting a Doom engine."

%files
%doc CREDITS.txt freedoom-manual*.pdf README.html
%license COPYING.txt
%_datadir/doom/

%changelog
* Mon Jan 29 2024 Jan Engelhardt <jengelh@inai.de>
- Update to release 0.13.0
  * Boom features were removed
  * Hall of mirror effects greatly reduced / visplane overflows
    fixed.
  * New levels: E1M9, E2M2, E2M3, E2M4, E2M7, E2M8, E3M5, MAP07,
    MAP21 and MAP27.
  * Lots of new music including most of FreeDM music.
  * New boss brain sounds.
  * Colorblind-friendly keys and key indicators.
  * Various revisions to sprites and textures.
  * Improved kerning for menu text.
  * Improved weapon sprites generally.
  * SSG replacement restored to updated take on older version.
  * Revised polaric energy weapon.
  * Double-barreled shotgun flash timing bug fixed in built-in
    DeHackEd.
  * Esa Repo (Espi)'s old STAR* textures are now included under
    ESPI*.
  * A STARBR1 texture is now included as a counterpart to STARBR2.
  * Numerous additional grey and METAL2-based textures also
    available.
  * Boss brain wall was re-done.
  * Wolfenstein replacements completely redone.
* Fri Nov  1 2019 Markus S <kamikazow@opensuse.org>
- Update to 0.12.1
  * The manual is now rendered as PDF.
  * Final Doom compatibility de-emphasized. Where it creates
    conflicts with Doom II mods or texture definitions, the the
    Doom II side of things gets preferred. Final Doom-specific
    maps and mods may never look completely right in Freedoom, as
    a result.
  * Phase 1 received a lot of mapping changes with improved
    difficulty levels. There is a new C3M5.
  * Phase 2 MAP01 received an overhaul, simplifying its design in
    significant ways to improve the flow around the level.
  * Two maps in Phase 2 were replaced due to being recreations of
    Doom II maps.
  * Maps in Phase 2 in general have had some slight
    re-arrangement based on difficulty levels and themes. A new
    MAP06 is included, while the old one took the MAP18 slot.
  * All levels are now guaranteed to have co-op and deathmatch starts.
  * New sprites for power-ups (stealth, overdrive, and ultra-overdrive)
    and Arch Vile.
  * Some weapon and ammo sprites have been tweaked and improved.
  * Completed and enhanced set of Evilution and Plutonia textures.
  * New skull-switches by MissLav.
  * New SKY4 based on an astronomy photograph.
  * Tweaked player sprites and HUD face.
  * New music tracks in C1M2, C2M3, C2M8, MAP03, MAP12, MAP22,
    MAP25, MAP26, MAP27, DM03, DM06, DM09, DM17, DM24, DM31, and
    DM32.
  * Metainfo (formerly appdata) and desktop files have been
    brought up to the latest standard specifications and
    recommendations, using reverse-DNS for the project
    identifier, and a self-evaluated content rating.
  * Phase 2’s internal DEMO1 has been replaced, thanks to some
    odd vanilla quirks that could cause it to desync in some (but
    not all) conditions.
  * The sailor monster type is formally banished from Freedoom’s
    own levels, and remaining uses of it were removed.
* Mon Jan  1 2018 avindra@opensuse.org
- Update to new upstream release 0.11.3:
  * allows building from source using deutex 5.0
* Tue Jul  4 2017 jengelh@inai.de
- Update to new upstream release 0.11 (2017-02-16)
  * Lots of new music.
  * New levels, including C1M1 kicking off Phase 1.
  * Aquatex: over 200 new textures for mappers to use.
  * New intermission screens.
  * Some new weapon sprites: new pistol, new pickups.
  * New medkit and armor pickup sprites.
- Update to new upstream release 0.11.1 (2017-02-22)
  * 1%% armor bonus pickups are recolored from red to green.
  * New textures compatible with TNT: Evilution
  * New pain bringer and pain lord sprites, replacing old concept
    art-derived ones.
  * A few map errors are fixed, including misaligned textures,
    leftover Boom specials, and it should no longer be possible
    to get stuck between a rock and a tree in Phase 1 C1M1.
  * Brand new Phase 1 C3M1, replacing an old Doom-inspired level.
  * Widescreen statusbar for ZDoom was removed. This created
    incompatibility with some mods.
  * Fixed intermission text after using the secret exit in
    Phase 2 MAP31, where obituary texts were incorrectly
    displayed instead.
- Update to new upstream release 0.11.2 (2017-03-15)
  * Missing multiplayer starts have been added to several levels.
    No map should be lacking anymore.
  * A few mapping errors were repaired by changing sector heights.
  * Par times for Phase 1 have been added.
* Tue Jul 26 2016 jengelh@inai.de
- Update description for dropped recommendation.
* Sat May  7 2016 mailaender@opensuse.org
- Drop recommends for a Doom engine
* Sat Mar 26 2016 mailaender@opensuse.org
- Update to new upstream release 0.10.1
  * Brand new status bar.
  * New sprites for the serpent and orb monster.
  * New HUD graphics for the single- and double-barrel shotguns, missile launcher, and SKAG.
  * New pain sounds for many monsters and the player.
  * New maps in Phase 1 and Phase 2.
  * New file names no longer conflict with Doom's
  * FreeDM and Phase 1 have grown out of the shadows of the project and have seen rapid advances.
  * New text font to replace the old one in all menus, in-game text, and status-bar HUD.
  * New zombie, shotgun zombie, and assault tripod sprites by a skilled pixel artist.
  * New sounds for the dark soldier.
  * More complete support for Final Doom mods, adding many more textures missing to support mods for both TNT: Evilution and The Plutonia Experiment.
* Fri Jan  3 2014 jengelh@inai.de
- Update to new upstream release 0.8
  * Ultimate Freedoom's episode 4 is now the Cacoward-winning Double
  Impact. Many maps have been updated, and a few sprites and sounds
  have been upgraded as well.
- Remove signature verification as sig files are no longer provided
* Wed May  1 2013 jengelh@inai.de
- Update to new upstream release 0.8~beta1
  * Various map, sprite and texture updates
- Package freedoom-ultimate as well
- Do not hard-require prboom; freedoom works with any engine
- Signature verification
- Wrap description at 70 cols
* Tue May  3 2011 claes.backstrom@opensuse.org
- updated to 0.7
* Mon Feb 15 2010 prusnak@suse.cz
- updated to 0.6.4
* Tue Jul  1 2008 claes.backstrom@fsfe.org
- New upstream version 0.6.2
* Wed Nov 21 2007 claes.backstrom@fsfe.org
- Initial package built from Fedora package (0.5-4)
